@@ -40,7 +40,7 @@ struct permchain {
     struct permchain *next;
 };
 
-struct permchain *permchain_create()
+struct permchain *permchain_create(void)
 {
     struct permchain *pc = malloc(sizeof(struct permchain));
     pc->mask = 0000;
@@ -67,6 +67,8 @@ static int add_chmod_rule_to_permchain(const char *start, const char *end,
 
     int len = end - start;
     char *buf = malloc((len + 1) * sizeof(char));
+    if (buf == NULL)
+        return -1;
     const char *p = buf;
 
     enum {LHS, RHS} state = LHS;
@@ -149,8 +151,18 @@ error:
 static int add_octal_rule_to_permchain(const char *start, const char *end,
                                        struct permchain *pc)
 {
+    // Make [start..end[ available as a null-terminated string to `strtol`
+    const int len = end - start;
+    char * const buf = malloc((len + 1) * sizeof(char));
+    if (buf == NULL)
+        return -1;
+    memcpy(buf, start, len);
+    buf[len] = '\0';
+
     struct permchain *newpc = permchain_create();
-    long mode = strtol(start, NULL, 8);
+
+    long mode = strtol(buf, NULL, 8);
+    free(buf);
 
     if (mode < 0 || mode > 0777) {
         permchain_destroy(newpc);
@@ -230,10 +242,11 @@ mode_t permchain_apply(struct permchain *pc, mode_t tgtmode)
 
     while (pc != NULL) {
         #if BINDFS_DEBUG
-        if (pc->op == 'o')
+        if (pc->op == 'o') {
             DPRINTF("STAT MODE: %o, op = %c %o", tgtmode, pc->op, pc->mode.as_octal);
-        else
+        } else if (pc->op != '\0') {
             DPRINTF("STAT MODE: %o, op = %c%s", tgtmode, pc->op, pc->mode.as_operands);
+        }
         #endif
 
         if (pc->op == '\0') {
